#! /bin/sh


#
# systeminfo.sh - System information gathering script
# by Kirk Waingrow
#
# V1.0 - Support only RH/FC, a limited filesystems and disk devices
#
#        CYA STATEMENT: *** USE AT YOUR OWN RISK ***
#        As is the script does not write over or near any system files,
#        unless someone modifies it to do so. ALWAYS TEST THE SCRIPT
#        ON A NON-PRODUCTION SYSTEM.
#
version="1.0 - 3/2006"

HST=`hostname -s`
DPATH="/tmp/systeminfo/$HST"

if [ ! -d "$DPATH" ]; then
  mkdir -p $DPATH
fi


general_p1()
{
echo "CURRENT SYSTEM INFORMATION AS of `date`"
echo
echo "Hostname: `hostname -s`"
echo "Domain: `hostname -d`"
echo "Host Alias: `hostname -a`"
echo "YP Domain: `hostname -d`"
echo "hostID: `hostid`"
echo
echo "Uptime : `uptime `"
}


network_base()
{
echo
for i in `ifconfig | grep Link | awk '{ print $1 }' | grep -v lo`
do
  echo "Network $i IP: `ifconfig $i | awk 'NR==2 { print $2}'|awk -F":" '{print $2}'`"
  echo "Network $i Setting:`mii-tool | grep $i: | cut -d':' -f2-`"
  echo "Network $i Netmask: `ifconfig $i | awk 'NR==2 { print $4}'|awk -F":" '{print $2}'`"
  echo "Network $i Hardware Addr: `ifconfig $i | awk 'NR==1 { print $5}'`"
  echo "Network $i txqueuelen: `ifconfig $i | awk 'NR==7 { print $2}'|awk -F":" '{print $2}'`"
  echo
done 
echo "Default Route Interface: `route | grep default | awk '{ print $8 }'`"
echo "Default Route IP: `route | grep default | awk '{ print $2 }'`"

DNSSERVER=`nslookup -sil host | grep "Server:" | awk '{ print $2}'`
SNAME=`nslookup -sil $DNSSERVER | grep "name =" | awk -F'=' '{ print $2}'`

echo "DNS Server: $DNSSERVER"
echo "DNS Server Name: $SNAME"
}


general_p2()
{
echo
echo "OS Distribution Name: `uname -s`"
echo "OS Release: `uname -r`"
echo "OS Name: `uname -o`"
echo "Machine Name: `uname -m`"
echo "Hardware Platform: `uname -i`"
echo "Libc Name: `rpm -qa | grep -i libc-[0-9] | cut -d'-' -f1`";
echo "Libc Version: `rpm -qa | grep -i libc-[0-9] | cut -d'-' -f2-`";
echo
echo "Processor Type: `uname -p`"
echo "Num Processors: `grep processor /proc/cpuinfo | wc -l |awk '{print $1}'`"
command=`grep processor /proc/cpuinfo | awk '{ print $3}' | tail -1`
echo -n "Hyperthreading is "
if [ $command -gt 1 ]; then
  echo "ON"
else
  echo "OFF"
fi
echo "Memory: `procinfo | grep "Mem:" | awk '{ print $2}'`"
echo "Timezone: `date +%Z`"
echo "Init Level: `grep ":initdefault:" /etc/inittab | cut -d":" -f2`"
}


chk_config()
{
echo; echo
echo "CHECK CONFIG:"
echo "=-=-=-=-=-=-=-=-=-=--=-=-=-=-=-=-=-=-="
chkconfig --list
}

diskinfo()
{
echo
echo
echo "MOUNTED DISKS:"
echo "=-=-=-=-=-=-=-=-=-=--=-=-=-=-=-=-=-=-="
df

echo
echo
echo "FILES SYSTEM TABLE"
echo "=-=-=-=-=-=-=-=-=-=--=-=-=-=-=-=-=-=-="
cat /etc/fstab

##
## ASSUMES Disks are ext3 and sd|hd|cciss|ida
##
echo; echo
echo "DISK PARTITION TABLE"
echo "=-=-=-=-=-=-=-=-=-=--=-=-=-=-=-=-=-=-="
for i in `mount -l | grep ext3 | cut -d" " -f1 `
do
  found=`echo $i | egrep '(cciss|ida)'`
  if [ -n "$found" ]; then
    D=`echo $i | cut -d"p" -f1`
    fdisk -l $D
  fi
  found=`echo $i | egrep '(sd|hd)'`
  if [ -n "$found" ]; then
    D=`echo $i | cut -c1-8`
    fdisk -l $D
  fi
done

echo; echo
echo "SWAP:"
echo "=-=-=-=-=-=-=-=-=-=--=-=-=-=-=-=-=-=-="
swapon -s

}

networkinfo()
{
echo; echo
echo "NETWORK INTERFACE INFORMATION"
echo "=-=-=-=-=-=-=-=-=-=--=-=-=-=-=-=-=-=-="
ifconfig

echo; echo
echo "DNS RESOLVER - /etc/resolv.conf"
echo "=-=-=-=-=-=-=-=-=-=--=-=-=-=-=-=-=-=-="
cat /etc/resolv.conf

echo; echo
echo "ROUTING TABLE"
echo "=-=-=-=-=-=-=-=-=-=--=-=-=-=-=-=-=-=-="
route
}


systeminfo()
{
echo; echo
echo "KERNEL MODULES"
echo "=-=-=-=-=-=-=-=-=-=--=-=-=-=-=-=-=-=-="
lsmod

echo; echo
echo "ULIMIT SETTINGS"
echo "=-=-=-=-=-=-=-=-=-=--=-=-=-=-=-=-=-=-="
ulimit -a

echo ; echo
echo "EXTRA CPU INFORMATION"
echo "=-=-=-=-=-=-=-=-=-=--=-=-=-=-=-=-=-=-="
cat /proc/cpuinfo

echo ; echo
echo "EXTRA MEMORY INFORMATION"
echo "=-=-=-=-=-=-=-=-=-=--=-=-=-=-=-=-=-=-="
cat /proc/meminfo

echo ; echo
echo "PROC INFO"
echo "=-=-=-=-=-=-=-=-=-=--=-=-=-=-=-=-=-=-="
procinfo

}


sockets()
{
echo; echo
echo "LISTENING SOCKET PORTS"
echo "=-=-=-=-=-=-=-=-=-=--=-=-=-=-=-=-=-=-="
netstat -an | grep LISTEN
}


software()
{
echo; echo
echo "SOFTWARE INFORMATION"
echo "=-=-=-=-=-=-=-=-=-=--=-=-=-=-=-=-=-=-="
rpm -qa --queryformat '%-15{NAME} %{VERSION}-%-15{RELEASE} %-20{SUMMARY}\n' | sort
}


croninfo()
{
list=`cd /var/spool/cron; ls -1`
for i in $list
do
  if [ -s "/var/spool/cron/$i" ]; then
   echo
   echo
   echo "CRONTAB ENTRY - $i"
   echo "=-=-=-=-=-=-=-=-=-=--=-=-=-=-=-=-=-=-="
   echo
   cat /var/spool/cron/$i
  fi
done
}


proctable()
{
echo; echo
echo "LAST RUN TOP"
echo "=-=-=-=-=-=-=-=-=-=--=-=-=-=-=-=-=-=-="
top -bn 1

echo; echo
echo "LAST RUN PROCESS TABLE"
echo "=-=-=-=-=-=-=-=-=-=--=-=-=-=-=-=-=-=-="
ps -efw
}

dmesginfo()
{
echo; echo
echo "DMESG"
echo "=-=-=-=-=-=-=-=-=-=--=-=-=-=-=-=-=-=-="
dmesg
}

indexpage()
{
 cat << EOF
	<HTML>
	<title>$HST System Information</test>
	<FRAMESET cols="20%, 80%">
      	<FRAME src="./menu.html">
  	<FRAME src="./general.txt" name=primary>
	</frameset>
	</HTML> 

EOF
}


menupage()
{
  cat << EOF

	<title>Menu</test>
	<center><b>$HST</b><br>System Info Menu</center><br><hr><p>
   	<A href=$HST.txt target=primary>Show All</a><p>
   	<A href=general.txt target=primary>General Info</a><br>
   	<A href=system.txt target=primary>System Configs</a><br>
   	<A href=disks.txt target=primary>Disks</a><br>
   	<A href=network.txt target=primary>Network</a><br>
   	<A href=software.txt target=primary>Software Packages</a><br>
   	<A href=cron.txt target=primary>Cron Jobs</a><br>
   	<A href=sockets.txt target=primary>Socket Ports</a><br>
   	<A href=proc.txt target=primary>Top/Proc Table</a><br>
   	<A href=chkconfig.txt target=primary>chkconfig</a><br>
   	<A href=dmesg.txt target=primary>dmesg</a><br>
	<pre>

	</pre>
	<hr>
	Version: $version<p>
EOF

}

###
### GENERATE REGULAR FILE
###
build_file()
{
  general_p1
  network_base
  general_p2	
  chk_config	
  diskinfo
  networkinfo
  systeminfo	
  sockets	
  software	
  croninfo	
  proctable	
  dmesginfo
}


# UNCOMMENT LINE IF YOU WANT TO SEE STDOUT
#build_file 

#OUTPUT STRAIGHT TO A FILE
build_file > $DPATH/$HST.txt
echo
echo "Outfile: $DPATH/$HST.txt"


###
### GENERATE WEB PAGES
###
indexpage	> $DPATH/index.html
menupage	> $DPATH/menu.html
general_p1 	> $DPATH/general.txt
network_base 	>> $DPATH/general.txt
general_p2 	>> $DPATH/general.txt	
chk_config	> $DPATH/chkconfig.txt	
diskinfo	> $DPATH/disks.txt	
networkinfo	> $DPATH/network.txt
network_base	>> $DPATH/network.txt
systeminfo	> $DPATH/system.txt	
sockets	> $DPATH/sockets.txt
software	> $DPATH/software.txt
croninfo	> $DPATH/cron.txt
proctable	> $DPATH/proc.txt
dmesginfo	> $DPATH/dmesg.txt
  
echo "HTML Start Page: $DPATH/index.html"
echo


